auth

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 17, 2015 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Auth

type Auth struct {
	Tokens map[string]bool
}

Auth is a provider of auth token management/lookup. TODO this is stubbed and needs to be DB/cache enabled.

func New

func New() *Auth

New is a factory method that returns an instance of Auth.

func (*Auth) Valid

func (t *Auth) Valid(tk string) bool

Valid returns true if the token was found and is valid.

Jump to